@@ -42,6 +42,7 @@ from gftools.utils import (
 from gftools.packager.build import build_to_directory
 import sys
 from gftools.push.trafficjam import TRAFFIC_JAM_ID
+from gftools.article import fix_article
 
 
 log = logging.getLogger("gftools.packager")
@@ -88,8 +89,8 @@ PR_CHECKLIST = """
 - [ ] The PR is linked to the corresponding issue
 
 ### QA
-- [ ] Fontbakery checks are reviewed and failing checks are resolved in collaboration with the upstream font development team
-- [ ] Diffenator2 regression checks for revisions on all projects that are currently in production
+- [ ] Fontspector checks are reviewed and failing checks are resolved in collaboration with the upstream font development team
+- [ ] Diffenator2 and 3 regression checks for revisions on all projects that are currently in production
 - [ ] The article has no typos, images are properly linked and correctly sized
 - [ ] OFL.txt contains the correct license URL (https://openfontlicense.org)
 
@@ -100,7 +101,6 @@ PR_CHECKLIST = """
 ### Release
 - [ ] Designers bio info have to be present in the designer catalog (at least an issue should be opened for tracking this, if they are not)
 - [ ] Check designers order in metadata.pb, since the first one of the list appears as “principal designer”
-- [ ] Social media formatted visual assets for all new commissioned projects in the Drive directory, communicate with the repository Maintainer so that they can push this content to the Social Media tracker spreadsheet
 - [ ] Social media content draft for all new commissioned projects in the Drive directory and Social Media tracker spreadsheet, communicate with the repository Maintainer so that they can push this content to the Social Media tracker spreadsheet
 - [ ] `minisite_url` definition in the METADATA.pb file for commissioned projects
 - [ ] `tags` are added for NEW FONTS
@@ -704,6 +704,10 @@ def make_package(
         packaged = package_family(
             family_path, metadata, latest_release, build_from_source, **kwargs
         )
+        article_path = family_path / "article"
+        if article_path.exists():
+            log.info(f"Fixing article in '{article_path}'")
+            fix_article(article_path, inplace=True)
         title, msg, branch = commit_family(
             branch, family_path, metadata, repo, head_repo, issue_number
         )
